==> jc-1.4.0.tar.gz: soot/Timers.h <==
// public class soot.Timers

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1654606c953cb519 soot_Timers

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Timers_H_
#define _JC_soot_Timers_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Timer$object;
struct _jc_soot_Timers$object;

// Typedefs
typedef struct _jc_soot_Timers$sub_refs	_jc_soot_Timers$sub_refs;
typedef struct _jc_soot_Timers$sub_nonrefs	_jc_soot_Timers$sub_nonrefs;
typedef struct _jc_soot_Timers$refs	_jc_soot_Timers$refs;
typedef struct _jc_soot_Timers$nonrefs	_jc_soot_Timers$nonrefs;
typedef struct _jc_soot_Timers$object	_jc_soot_Timers$object;

typedef const struct _jc_soot_Timers$vmethods	_jc_soot_Timers$vmethods;
typedef const struct _jc_soot_Timers$vtable	_jc_soot_Timers$vtable;
typedef const struct _jc_soot_Timers$vtype	_jc_soot_Timers$vtype;

// Constructors
extern void _jc_soot_Timers$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$paddedLeftOf$0193a993372e4bde(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_java_lang_String$object *, jint);
extern void _jc_soot_Timers$method$printProfilingInformation$19bc08a205987922(_jc_env *, struct _jc_soot_Timers$object *);
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$toFormattedString$f4b9ea761aa8f12d(_jc_env *, struct _jc_soot_Timers$object *, jdouble);
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$toTimeString$49a393ce4a3ea603(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Timer$object *, jlong);
extern jdouble _jc_soot_Timers$method$truncatedOf$ac451cc081880f56(_jc_env *, struct _jc_soot_Timers$object *, jdouble, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_Timers$method_info$paddedLeftOf$0193a993372e4bde;
extern _jc_method _jc_soot_Timers$method_info$printProfilingInformation$19bc08a205987922;
extern _jc_method _jc_soot_Timers$method_info$toFormattedString$f4b9ea761aa8f12d;
extern _jc_method _jc_soot_Timers$method_info$toTimeString$49a393ce4a3ea603;
extern _jc_method _jc_soot_Timers$method_info$truncatedOf$ac451cc081880f56;

// Static methods
extern struct _jc_soot_Timers$object *_jc_soot_Timers$method$v$fd72f5ea93698e5d(_jc_env *);

// Virtual methods structure
struct _jc_soot_Timers$vmethods {
	struct _jc_java_lang_String$object	*(*paddedLeftOf$0193a993372e4bde)(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_java_lang_String$object *, jint);
	void	(*printProfilingInformation$19bc08a205987922)(_jc_env *, struct _jc_soot_Timers$object *);
	struct _jc_java_lang_String$object	*(*toFormattedString$f4b9ea761aa8f12d)(_jc_env *, struct _jc_soot_Timers$object *, jdouble);
	struct _jc_java_lang_String$object	*(*toTimeString$49a393ce4a3ea603)(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Timer$object *, jlong);
	jdouble	(*truncatedOf$ac451cc081880f56)(_jc_env *, struct _jc_soot_Timers$object *, jdouble, jint);
};

// Vtable
struct _jc_soot_Timers$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Timers$vmethods	soot_Timers;
};

// Vtype
struct _jc_soot_Timers$vtype {
	_jc_type			type;
	_jc_soot_Timers$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Timers$sub_refs {
	struct _jc_soot_Timer$object	*copiesTimer;
	struct _jc_soot_Timer$object	*defsTimer;
	struct _jc_soot_Timer$object	*usesTimer;
	struct _jc_soot_Timer$object	*liveTimer;
	struct _jc_soot_Timer$object	*splitTimer;
	struct _jc_soot_Timer$object	*packTimer;
	struct _jc_soot_Timer$object	*cleanup1Timer;
	struct _jc_soot_Timer$object	*cleanup2Timer;
	struct _jc_soot_Timer$object	*conversionTimer;
	struct _jc_soot_Timer$object	*cleanupAlgorithmTimer;
	struct _jc_soot_Timer$object	*graphTimer;
	struct _jc_soot_Timer$object	*assignTimer;
	struct _jc_soot_Timer$object	*resolveTimer;
	struct _jc_soot_Timer$object	*totalTimer;
	struct _jc_soot_Timer$object	*splitPhase1Timer;
	struct _jc_soot_Timer$object	*splitPhase2Timer;
	struct _jc_soot_Timer$object	*usePhase1Timer;
	struct _jc_soot_Timer$object	*usePhase2Timer;
	struct _jc_soot_Timer$object	*usePhase3Timer;
	struct _jc_soot_Timer$object	*defsSetupTimer;
	struct _jc_soot_Timer$object	*defsAnalysisTimer;
	struct _jc_soot_Timer$object	*defsPostTimer;
	struct _jc_soot_Timer$object	*liveSetupTimer;
	struct _jc_soot_Timer$object	*liveAnalysisTimer;
	struct _jc_soot_Timer$object	*livePostTimer;
	struct _jc_soot_Timer$object	*aggregationTimer;
	struct _jc_soot_Timer$object	*grimpAggregationTimer;
	struct _jc_soot_Timer$object	*deadCodeTimer;
	struct _jc_soot_Timer$object	*propagatorTimer;
	struct _jc_soot_Timer$object	*buildJasminTimer;
	struct _jc_soot_Timer$object	*assembleJasminTimer;
	struct _jc_soot_Timer$object	*resolverTimer;
	struct _jc_soot_Timer$object	*fieldTimer;
	struct _jc_soot_Timer$object	*methodTimer;
	struct _jc_soot_Timer$object	*attributeTimer;
	struct _jc_soot_Timer$object	*locatorTimer;
	struct _jc_soot_Timer$object	*readTimer;
};

// Reference instance fields (object)
struct _jc_soot_Timers$refs {
    _jc_soot_Timers$sub_refs	soot_Timers;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Timers$sub_nonrefs {
	jint	totalFlowNodes;
	jint	totalFlowComputations;
	jint	conversionLocalCount;
	jint	cleanup1LocalCount;
	jint	splitLocalCount;
	jint	assignLocalCount;
	jint	packLocalCount;
	jint	cleanup2LocalCount;
	jint	conversionStmtCount;
	jint	cleanup1StmtCount;
	jint	splitStmtCount;
	jint	assignStmtCount;
	jint	packStmtCount;
	jint	cleanup2StmtCount;
	jlong	stmtCount;
};

// Non-reference instance fields (object)
struct _jc_soot_Timers$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Timers$sub_nonrefs	soot_Timers;
};

// Object instance structure
struct _jc_soot_Timers$object {
	_jc_soot_Timers$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Timers$vtype	*vtype;
	_jc_soot_Timers$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Timers$vtype _jc_soot_Timers$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Timers, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Timers$class_object;

#endif	/* _JC_soot_Timers_H_ */

==> jc-1.4.6.tar.gz: soot/Timers.h <==
// public class soot.Timers

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1654606c953cb519 soot_Timers

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Timers_H_
#define _JC_soot_Timers_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Timer$object;
struct _jc_soot_Timers$object;

// Typedefs
typedef struct _jc_soot_Timers$sub_refs	_jc_soot_Timers$sub_refs;
typedef struct _jc_soot_Timers$sub_nonrefs	_jc_soot_Timers$sub_nonrefs;
typedef struct _jc_soot_Timers$refs	_jc_soot_Timers$refs;
typedef struct _jc_soot_Timers$nonrefs	_jc_soot_Timers$nonrefs;
typedef struct _jc_soot_Timers$object	_jc_soot_Timers$object;

typedef const struct _jc_soot_Timers$vmethods	_jc_soot_Timers$vmethods;
typedef const struct _jc_soot_Timers$vtable	_jc_soot_Timers$vtable;
typedef const struct _jc_soot_Timers$vtype	_jc_soot_Timers$vtype;

// Constructors
extern void _jc_soot_Timers$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$paddedLeftOf$0193a993372e4bde(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_Timers$method$printProfilingInformation$19bc08a205987922(_jc_env *, struct _jc_soot_Timers$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$toFormattedString$f4b9ea761aa8f12d(_jc_env *, struct _jc_soot_Timers$object *, jdouble) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_Timers$method$toTimeString$49a393ce4a3ea603(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Timer$object *, jlong) _JC_JCNI_ATTR;
extern jdouble _jc_soot_Timers$method$truncatedOf$ac451cc081880f56(_jc_env *, struct _jc_soot_Timers$object *, jdouble, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_Timers$method_info$paddedLeftOf$0193a993372e4bde;
extern _jc_method _jc_soot_Timers$method_info$printProfilingInformation$19bc08a205987922;
extern _jc_method _jc_soot_Timers$method_info$toFormattedString$f4b9ea761aa8f12d;
extern _jc_method _jc_soot_Timers$method_info$toTimeString$49a393ce4a3ea603;
extern _jc_method _jc_soot_Timers$method_info$truncatedOf$ac451cc081880f56;

// Static methods
extern struct _jc_soot_Timers$object *_jc_soot_Timers$method$v$fd72f5ea93698e5d(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_Timers$vmethods {
	struct _jc_java_lang_String$object	*(*paddedLeftOf$0193a993372e4bde)(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	void	(*printProfilingInformation$19bc08a205987922)(_jc_env *, struct _jc_soot_Timers$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toFormattedString$f4b9ea761aa8f12d)(_jc_env *, struct _jc_soot_Timers$object *, jdouble) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toTimeString$49a393ce4a3ea603)(_jc_env *, struct _jc_soot_Timers$object *, struct _jc_soot_Timer$object *, jlong) _JC_JCNI_ATTR;
	jdouble	(*truncatedOf$ac451cc081880f56)(_jc_env *, struct _jc_soot_Timers$object *, jdouble, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_Timers$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Timers$vmethods	soot_Timers;
};

// Vtype
struct _jc_soot_Timers$vtype {
	_jc_type			type;
	_jc_soot_Timers$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Timers$sub_refs {
	struct _jc_soot_Timer$object	*copiesTimer;
	struct _jc_soot_Timer$object	*defsTimer;
	struct _jc_soot_Timer$object	*usesTimer;
	struct _jc_soot_Timer$object	*liveTimer;
	struct _jc_soot_Timer$object	*splitTimer;
	struct _jc_soot_Timer$object	*packTimer;
	struct _jc_soot_Timer$object	*cleanup1Timer;
	struct _jc_soot_Timer$object	*cleanup2Timer;
	struct _jc_soot_Timer$object	*conversionTimer;
	struct _jc_soot_Timer$object	*cleanupAlgorithmTimer;
	struct _jc_soot_Timer$object	*graphTimer;
	struct _jc_soot_Timer$object	*assignTimer;
	struct _jc_soot_Timer$object	*resolveTimer;
	struct _jc_soot_Timer$object	*totalTimer;
	struct _jc_soot_Timer$object	*splitPhase1Timer;
	struct _jc_soot_Timer$object	*splitPhase2Timer;
	struct _jc_soot_Timer$object	*usePhase1Timer;
	struct _jc_soot_Timer$object	*usePhase2Timer;
	struct _jc_soot_Timer$object	*usePhase3Timer;
	struct _jc_soot_Timer$object	*defsSetupTimer;
	struct _jc_soot_Timer$object	*defsAnalysisTimer;
	struct _jc_soot_Timer$object	*defsPostTimer;
	struct _jc_soot_Timer$object	*liveSetupTimer;
	struct _jc_soot_Timer$object	*liveAnalysisTimer;
	struct _jc_soot_Timer$object	*livePostTimer;
	struct _jc_soot_Timer$object	*aggregationTimer;
	struct _jc_soot_Timer$object	*grimpAggregationTimer;
	struct _jc_soot_Timer$object	*deadCodeTimer;
	struct _jc_soot_Timer$object	*propagatorTimer;
	struct _jc_soot_Timer$object	*buildJasminTimer;
	struct _jc_soot_Timer$object	*assembleJasminTimer;
	struct _jc_soot_Timer$object	*resolverTimer;
	struct _jc_soot_Timer$object	*fieldTimer;
	struct _jc_soot_Timer$object	*methodTimer;
	struct _jc_soot_Timer$object	*attributeTimer;
	struct _jc_soot_Timer$object	*locatorTimer;
	struct _jc_soot_Timer$object	*readTimer;
};

// Reference instance fields (object)
struct _jc_soot_Timers$refs {
    _jc_soot_Timers$sub_refs	soot_Timers;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Timers$sub_nonrefs {
	jint	totalFlowNodes;
	jint	totalFlowComputations;
	jint	conversionLocalCount;
	jint	cleanup1LocalCount;
	jint	splitLocalCount;
	jint	assignLocalCount;
	jint	packLocalCount;
	jint	cleanup2LocalCount;
	jint	conversionStmtCount;
	jint	cleanup1StmtCount;
	jint	splitStmtCount;
	jint	assignStmtCount;
	jint	packStmtCount;
	jint	cleanup2StmtCount;
	jlong	stmtCount;
};

// Non-reference instance fields (object)
struct _jc_soot_Timers$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Timers$sub_nonrefs	soot_Timers;
};

// Object instance structure
struct _jc_soot_Timers$object {
	_jc_soot_Timers$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Timers$vtype	*vtype;
	_jc_soot_Timers$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Timers$vtype _jc_soot_Timers$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Timers, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Timers$class_object;

#endif	/* _JC_soot_Timers_H_ */
